@@ -1,9 +1,9 @@
 import re
 
-from rigidanalytics_tracker import TrackerABC
+from rigidanalytics_tracker import Tracker
 
 
-class DjangoTracker(TrackerABC):
+class DjangoTracker(Tracker):
 
     def __init__(self):
         self.init_tracker()
